create table ArealFcst
(
lid             char(8)                  not null,
pe              char(2)                  not null,
dur             smallint                 not null,
ts              char(2)                  not null,
extremum        char(1)                  not null,
probability     smallfloat               not null,
validtime       datetime year to second  not null,
basistime       datetime year to second  not null,
value           float,
shef_qual_code  char(1),
quality_code    integer,
revision        smallint,
product_id      char(10),
producttime     datetime year to second,
postingtime     datetime year to second
)
extent size 512 
next   size 512
lock   mode row;

alter table ArealFcst add constraint primary key
      (lid, pe, dur, ts, extremum, probability, validtime, basistime)
      constraint ArealFcst_pk;

revoke all on ArealFcst from public;
grant  select, insert, update, delete on ArealFcst to public;

create index ArealFcst_time_ind on ArealFcst (basistime);

create table ArealObs
(
lid             char(8)  not null,
pe              char(2)  not null,
dur             smallint not null,
ts              char(2)  not null,
extremum        char(1)  not null,
obstime         datetime year to second  not null,
value           float,
shef_qual_code  char(1),
quality_code    integer,
revision        smallint,
product_id      char(10),
producttime     datetime year to second,
postingtime     datetime year to second
)
extent size 512
next   size 512
lock   mode row;

alter table ArealObs add constraint primary key
      (lid, pe, dur, ts, extremum, obstime)
      constraint ArealObs_pk;

revoke all on ArealObs from public;
grant  select, insert, update, delete on ArealObs to public;

create index ArealObs_time_ind on ArealObs (obstime);

create table CurPC
(
lid             char(8)  not null,
pe              char(2)  not null,
dur             smallint not null,
ts              char(2)  not null,
extremum        char(1)  not null,
obstime         datetime year to second  not null,
value           float,
shef_qual_code  char(1),
quality_code    integer,
revision        smallint,
product_id      char(10),
producttime     datetime year to second,
postingtime     datetime year to second
)
extent size 512
next   size 512
lock   mode row;

alter table CurPC add constraint primary key
      (lid, ts, extremum, obstime)
      constraint curpc_pk;

revoke all on CurPC from public;
grant  select, insert, update, delete on CurPC to public;

create index curpc_time_ind on CurPC (obstime);

create table CurPP
(
lid             char(8)  not null,
pe              char(2)  not null,
dur             smallint not null,
ts              char(2)  not null,
extremum        char(1)  not null,
obstime         datetime year to second  not null,
value           float,
shef_qual_code  char(1),
quality_code    integer,
revision        smallint,
product_id      char(10),
producttime     datetime year to second,
postingtime     datetime year to second
)
extent size 512
next   size 512
lock   mode row;

alter table CurPP add constraint primary key
      (lid, dur, ts, extremum, obstime)
      constraint curpp_pk;

revoke all on CurPP from public;
grant  select, insert, update, delete on CurPP to public;

create index curpptime_ind on CurPP (obstime);

create table HourlyPC 
(
lid               char(8)                  not null,
ts                char(2)                  not null,
obsdate		  datetime year to day     not null,
minute_offset     char(24),
hourly_qc         char(24),
hour1             smallint,
hour2             smallint,
hour3             smallint,
hour4             smallint,
hour5             smallint,
hour6             smallint,
hour7             smallint,
hour8             smallint,
hour9             smallint,
hour10            smallint,
hour11            smallint,
hour12            smallint,
hour13            smallint,
hour14            smallint,
hour15            smallint,
hour16            smallint,
hour17            smallint,
hour18            smallint,
hour19            smallint,
hour20            smallint,
hour21            smallint,
hour22            smallint,
hour23            smallint,
hour24            smallint
)
extent size 512
next   size 512
lock   mode row;

alter table HourlyPC add constraint primary key
      (lid, ts, obsdate)
      constraint hourlypc_pk;
	
create index hourlypc_time_ind on HourlyPC (obsdate);

revoke all on HourlyPC from public;
grant  select, insert, update, delete on HourlyPC to public;


create table HourlyPP 
(
lid               char(8)               not null,
ts                char(2)               not null,
obsdate		  datetime year to day  not null,
minute_offset     char(24),
hourly_qc         char(24),
hour1             smallint,
hour2             smallint,
hour3             smallint,
hour4             smallint,
hour5             smallint,
hour6             smallint,
hour7             smallint,
hour8             smallint,
hour9             smallint,
hour10            smallint,
hour11            smallint,
hour12            smallint,
hour13            smallint,
hour14            smallint,
hour15            smallint,
hour16            smallint,
hour17            smallint,
hour18            smallint,
hour19            smallint,
hour20            smallint,
hour21            smallint,
hour22            smallint,
hour23            smallint,
hour24            smallint
)
extent size 512
next   size 512
lock   mode row;

alter table HourlyPP add constraint primary key
      (lid, ts, obsdate)
      constraint hourlypp_pk;
	
create index hourlypp_time_ind on HourlyPP (obsdate);

revoke all on HourlyPP from public;
grant  select, insert, update, delete on HourlyPP to public;


create table RawPC 
(
lid             char(8)                  not null,
pe              char(2)                  not null,
dur             smallint                 not null,
ts              char(2)                  not null,
extremum        char(1)                  not null,
obstime         datetime year to second  not null,
value           float,
shef_qual_code  char(1),
quality_code    integer,
revision        smallint,
product_id      char(10),
producttime     datetime year to second,
postingtime     datetime year to second
)
extent size 1024
next   size 1024
lock   mode row;

alter table RawPC add constraint primary key
      (lid, ts, extremum, obstime)
      constraint rawpc_pk;
	
create index rawpc_time_ind on RawPC (obstime);

revoke all on RawPC from public;
grant  select, insert, update, delete on RawPC to public;


create table RawPother 
(
lid             char(8)                  not null,
pe              char(2)                  not null,
dur             smallint                 not null,
ts              char(2)                  not null,
extremum        char(1)                  not null,
obstime         datetime year to second  not null,
value           float,
shef_qual_code  char(1),
quality_code    integer,
revision        smallint,
product_id      char(10),
producttime     datetime year to second,
postingtime     datetime year to second
)
extent size 512
next   size 512
lock   mode row;

alter table RawPother add constraint primary key
      (lid, pe, dur, ts, extremum, obstime)
      constraint rawpother_pk;
	
create index rawpother_ind on RawPother (obstime);

revoke all on RawPother from public;
grant  select, insert, update, delete on RawPother to public;

create table RawPP
(
lid             char(8)                  not null,
pe              char(2)                  not null,
dur             smallint                 not null,
ts              char(2)                  not null,
extremum        char(1)                  not null,
obstime         datetime year to second  not null,
value           float,
shef_qual_code  char(1),
quality_code    integer,
revision        smallint,
product_id      char(10),
producttime     datetime year to second,
postingtime     datetime year to second
)
extent size 1024
next   size 1024
lock   mode row;

alter table RawPP add constraint primary key
      (lid, dur, ts, extremum, obstime)
      constraint rawpp_pk;
	
create index rawpp_ind on RawPP (obstime);

revoke all on RawPP from public;
grant  select, insert, update, delete on RawPP to public;
